@@ -26,12 +26,20 @@ def build(setup_kwargs: Any) -> None:
                         "src/zeroconf/_dns.py",
                         "src/zeroconf/_cache.py",
                         "src/zeroconf/_history.py",
+                        "src/zeroconf/_record_update.py",
                         "src/zeroconf/_listener.py",
                         "src/zeroconf/_protocol/incoming.py",
                         "src/zeroconf/_protocol/outgoing.py",
+                        "src/zeroconf/_handlers/answers.py",
                         "src/zeroconf/_handlers/record_manager.py",
+                        "src/zeroconf/_handlers/multicast_outgoing_queue.py",
                         "src/zeroconf/_handlers/query_handler.py",
+                        "src/zeroconf/_services/__init__.py",
+                        "src/zeroconf/_services/browser.py",
+                        "src/zeroconf/_services/info.py",
                         "src/zeroconf/_services/registry.py",
+                        "src/zeroconf/_updates.py",
+                        "src/zeroconf/_utils/ipaddress.py",
                         "src/zeroconf/_utils/time.py",
                     ],
                     compiler_directives={"language_level": "3"},  # Python 3
@@ -39,6 +47,7 @@ def build(setup_kwargs: Any) -> None:
                 cmdclass=dict(build_ext=BuildExt),
             )
         )
+        setup_kwargs["exclude_package_data"] = {pkg: ["*.c"] for pkg in setup_kwargs["packages"]}
     except Exception:
         if os.environ.get("REQUIRE_CYTHON"):
             raise
